CedarBackup3.actions.rebuild — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.rebuild

Implements the standard ‘rebuild’ action. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.rebuild.logger

CedarBackup3.actions.rebuild.executeRebuild(configPath, options, config)

  Executes the rebuild backup action.

  This function exists mainly to recreate a disc that has been “trashed” due to media or hardware problems. Note that the “stage complete” indicator isn’t checked for this action.

  Note that the rebuild action and the store action are very similar. The main difference is that while store only stores a single day’s staging directory, the rebuild action operates on multiple staging directories.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration

  Raises:

    - ValueError – Under many generic error conditions

    - IOError – If there are problems reading or writing files